@@ -32,10 +32,16 @@ class HeatExchanger(Block):
 
         if str(input_list[0]) in ["Heat Exchanger", "Scambiatore"]:
 
-            new_conn_input_product = self.main_class.find_connection_by_index(abs(input_list[1]))
-            new_conn_output_product = self.main_class.find_connection_by_index(abs(input_list[2]))
-            new_conn_input_fuel = self.main_class.find_connection_by_index(abs(input_list[3]))
-            new_conn_output_fuel = self.main_class.find_connection_by_index(abs(input_list[4]))
+            try:
+
+                new_conn_input_product = self.main_class.find_connection_by_index(abs(input_list[1]))
+                new_conn_output_product = self.main_class.find_connection_by_index(abs(input_list[2]))
+                new_conn_input_fuel = self.main_class.find_connection_by_index(abs(input_list[3]))
+                new_conn_output_fuel = self.main_class.find_connection_by_index(abs(input_list[4]))
+
+            except:
+
+                print(input_list)
 
             self.add_connection(new_conn_input_product, is_input=True, append_to_support_block=1)
             self.add_connection(new_conn_output_product, is_input=False, append_to_support_block=1)
@@ -74,15 +80,6 @@ class HeatExchanger(Block):
                     is_input = (elem > 0)
                     self.add_connection(new_conn, is_input=is_input, append_to_support_block=1)
 
-    def export_xml_other_parameters(self) -> ETree.Element:
-
-        other_tree = ETree.Element("Other")
-        return other_tree
-
-    def append_xml_other_parameters(self, input_list: ETree.Element):
-
-        pass
-
     def export_xml_connection_list(self) -> ETree.Element:
 
         xml_connection_list = ETree.Element("Connections")
